@@ -257,7 +257,7 @@ show_calendar_search_settings_dlg(GtkButton* button, gpointer user_data)
   GtkWidget* enable_time_frame_search_button = hildon_button_new(HILDON_SIZE_FINGER_HEIGHT,
 								 HILDON_BUTTON_ARRANGEMENT_VERTICAL);
   hildon_button_set_title(HILDON_BUTTON(enable_time_frame_search_button),
-			  gettext("Period"));
+			  dgettext("scout", "Interval"));
   search_time_settings_t* search_time_settings = g_new0(search_time_settings_t,1);
 
   search_time_settings->search_type = calendar_search_settings->search_type;
