@@ -2041,7 +2041,7 @@ _show_settings_dialog_cb(GtkButton* button, gpointer data)
   gtk_button_set_label(GTK_BUTTON(enable_contact_search), dgettext("osso-addressbook", "addr_ap_address_book"));
   gtk_button_set_label(GTK_BUTTON(enable_conversation_search), dgettext("rtcom-messaging-ui", "messaging_ap_conversations"));
   gtk_button_set_label(GTK_BUTTON(enable_calendar_search), dgettext("calendar", "cal_ap_name"));
-  gtk_button_set_label(GTK_BUTTON(enable_case_sensitve_search), gettext("case sensitive"));
+  gtk_button_set_label(GTK_BUTTON(enable_case_sensitve_search), dgettext("scout", "case sensitive"));
   
   gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(enable_contact_search), FALSE);
   gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(enable_conversation_search), FALSE);
@@ -2102,9 +2102,9 @@ _init_menu(ScoutWindow* self)
 								     GtkIconSize(HILDON_ICON_SIZE_FINGER));
   GtkWidget* case_sensitive_icon = gtk_image_new_from_file("/usr/share/pixmaps/scout/case_sensitive.png");
   
-  gtk_button_set_label(GTK_BUTTON(case_sensitive_search), gettext("case sensitive"));
-  gtk_button_set_label(GTK_BUTTON(show_calendar_search_settings), gettext("Calendar Search"));
-  gtk_button_set_label(GTK_BUTTON(show_conversations_search_settings), gettext("Conversations Search"));
+  gtk_button_set_label(GTK_BUTTON(case_sensitive_search), dgettext("scount", "case sensitive"));
+  gtk_button_set_label(GTK_BUTTON(show_calendar_search_settings), dgettext("scout", "Calendar Search"));
+  gtk_button_set_label(GTK_BUTTON(show_conversations_search_settings), dgettext("scout", "Conversations Search"));
   gtk_button_set_image(GTK_BUTTON(case_sensitive_search), case_sensitive_icon);
   gtk_button_set_image(GTK_BUTTON(show_calendar_search_settings), config_image_widget_cal);
   gtk_button_set_image(GTK_BUTTON(show_conversations_search_settings), config_image_widget_conv);
